@@ -148,7 +148,7 @@ class MarkKernelRow(Gtk.ListBoxRow):
             action = _("Remove")
         else:
             action = _("Install")
-        button = Gtk.CheckButton(f"{action} {kernel.version}{kernel.type}", False)
+        button = Gtk.CheckButton("%s %s%s" % (action, kernel.version, kernel.type), False)
         button.connect("toggled", self.on_checked)
         Gtk.ToggleButton.set_active(button, not version_id or (not supported and ACTIVE_KERNEL_VERSION > version_id))
         self.add(button)
@@ -190,7 +190,6 @@ class KernelRow(Gtk.ListBoxRow):
             label.set_margin_start(6)
             label.props.xalign = 0.5
             label.set_markup("<i>%s</i>" % title)
-            Gtk.StyleContext.add_class(Gtk.Widget.get_style_context(label), "dim-label")
             hbox.set_center_widget(label)
 
         if support_status:
@@ -232,11 +231,9 @@ class KernelRow(Gtk.ListBoxRow):
 
         button_box = Gtk.Box(orientation=Gtk.Orientation.HORIZONTAL)
         button = Gtk.Button()
-        Gtk.StyleContext.add_class(Gtk.Widget.get_style_context(button), "text-button")
         kernel = Kernel(version, kernel_type, origin, installed)
         button.connect("clicked", self.install_kernel, kernel)
         queuebutton = Gtk.Button()
-        Gtk.StyleContext.add_class(Gtk.Widget.get_style_context(queuebutton), "text-button")
         queuebutton.connect("clicked", self.queue_kernel, kernel)
         if installed:
             button.set_label(_("Remove"))
@@ -374,11 +371,6 @@ class KernelWindow():
 
         self.main_stack.add_named(main_box, "main_box")
 
-        if self.application.settings.get_boolean("hide-kernel-update-warning"):
-            self.main_stack.set_visible_child_name("status_refreshing")
-        else:
-            self.main_stack.set_visible_child(info_box)
-
         # Center on main window
         window_size = self.window.get_size()
         parent_size = self.application.window.get_size()
@@ -392,8 +384,10 @@ class KernelWindow():
         self.builder.get_object("cb_label").set_visible(self.allow_kernel_type_selection)
         self.builder.get_object("cb_kernel_type").set_visible(self.allow_kernel_type_selection)
 
-        # Build kernels list
-        self.refresh_kernels_list()
+        if self.application.settings.get_boolean("hide-kernel-update-warning"):
+            self.refresh_kernels_list()
+        else:
+            self.main_stack.set_visible_child(info_box)
 
     def refresh_kernels_list(self):
         self.status_refreshing_spinner.start()
@@ -405,10 +399,12 @@ class KernelWindow():
         RefreshKernelsThread(self).start()
 
     def refresh_kernels_list_done(self):
+        Gdk.threads_enter()
         self.stack.show_all()
         self.window.get_window().set_cursor(None)
         self.main_stack.set_visible_child_name("main_box")
         self.status_refreshing_spinner.stop()
+        Gdk.threads_leave()
 
     def build_kernels_list(self, kernels):
         now = datetime.now()
@@ -419,6 +415,9 @@ class KernelWindow():
         pages_needed = []
         pages_needed_sort = []
         self.marked_kernels = []
+        # ACTIVE_KERNEL_VERSION is used by the MarkKernelRow class
+        global ACTIVE_KERNEL_VERSION
+        ACTIVE_KERNEL_VERSION = "0"
         for kernel in kernels:
             values = kernel.split('###')
             if len(values) == 11:
@@ -428,8 +427,6 @@ class KernelWindow():
                 title = ""
                 if used:
                     title = _("Active")
-                    # ACTIVE_KERNEL_VERSION is used by the MarkKernelRow class
-                    global ACTIVE_KERNEL_VERSION
                     ACTIVE_KERNEL_VERSION = version_id
                 elif installed:
                     title = _("Installed")
@@ -531,7 +528,9 @@ class KernelWindow():
             if installed:
                 self.installed_kernels.append((kernel_type, version))
                 if not used:
+                    Gdk.threads_enter()
                     self.button_massremove.set_sensitive(True)
+                    Gdk.threads_leave()
                     self.remove_kernels_listbox.append(MarkKernelRow(Kernel(version, kernel_type, origin, installed),
                                                                             self.marked_kernels, version_id,
                                                                             newest_supported_in_series))
@@ -541,6 +540,7 @@ class KernelWindow():
         del(kernel_list_prelim)
 
         # add kernels to UI
+        Gdk.threads_enter()
         pages_needed_sort.sort(reverse=True)
         for page in pages_needed_sort:
             page = page[1]
@@ -557,13 +557,14 @@ class KernelWindow():
                 (version_id, version, pkg_version, kernel_type, page_label, label, installed, used, title, installable, origin, support_status) = kernel
                 if used:
                     currently_using = _("You are currently using the following kernel:")
-                    self.current_label.set_markup(f"<b>{currently_using} {label}{kernel_type}{f' ({support_status})' if support_status else ''}</b>")
+                    self.current_label.set_markup("<b>%s %s%s%s</b>" % (currently_using, label, kernel_type, ' (%s)' % support_status if support_status else ''))
                 if page_label == page:
                     row = KernelRow(version, pkg_version, kernel_type, label, installed, used, title,
                         installable, origin, support_status, self.window, self.application, self)
                     list_box.add(row)
 
             list_box.connect("row_activated", self.on_row_activated)
+        Gdk.threads_leave()
 
     def destroy_window(self, widget):
         self.window.destroy()
@@ -572,7 +573,7 @@ class KernelWindow():
         self.application.window.set_sensitive(True)
 
     def on_continue_clicked(self, widget, main_box):
-        self.main_stack.set_visible_child(main_box)
+        self.refresh_kernels_list()
 
     def on_info_checkbox_toggled(self, widget):
         self.application.settings.set_boolean("hide-kernel-update-warning", widget.get_active())
